# DiscordOAuth2
automatically follows through with the requests for Discord OAuth

***

## What I'm working on
- [x] Making the main function
  - [x] Make the auth url automatically, with the client_id, scopes, and a redirect uri
  - [x] Test the return of the url
  - [x] Add typing, docstrings, and follow [PEPs](https://peps.python.org) [8](https://peps.python.org/pep-0008/), [257](https://peps.python.org/pep-0257/), and [484](https://peps.python.org/pep-0484/)
    - [x] [PEP 8 (Style Guide For Python Guide)](https://peps.python.org/pep-0008/)
    - [x] [PEP 257 (Docstring Conventions)](https://peps.python.org/pep-0257/)
    - [x] [PEP 484 (Type Hints)](https://peps.python.org/pep-0484/)
- [ ] Succesfully upload to [PyPi.org](https://pypi.org)
